API reference
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   satlas2.models

Submodules
----------

satlas2.core module
-------------------

.. automodule:: satlas2.core
   :members:
   :undoc-members:
   :show-inheritance:

satlas2.interface module
------------------------

.. automodule:: satlas2.interface
   :members:
   :undoc-members:
   :show-inheritance:

satlas2.plotting module
-----------------------

.. automodule:: satlas2.plotting
   :members:
   :undoc-members:
   :show-inheritance: